@@ -1,21 +1,19 @@
-from requests import Session
-
 from je_api_testka.requests_wrapper.requests_data_structure import api_tester_method
 
-from je_api_testka.utils.api_test_exceptions import APITesterException
-from je_api_testka.utils.api_test_exceptions import APITesterGetDataException
-from je_api_testka.utils.get_api_data import get_api_response_data
+from je_api_testka.utils.exception.api_test_exceptions import APITesterException
+from je_api_testka.utils.exception.api_test_exceptions import APITesterGetDataException
+from je_api_testka.utils.get_data_strcture.get_api_data import get_api_response_data
 
-from je_api_testka.utils.api_test_eceptions_tag import api_test_get_data_error_message
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_get_data_error_message
 
-from je_api_testka.utils.api_test_eceptions_tag import api_test_get_error_message
-from je_api_testka.utils.api_test_eceptions_tag import api_test_put_error_message
-from je_api_testka.utils.api_test_eceptions_tag import api_test_delete_error_message
-from je_api_testka.utils.api_test_eceptions_tag import api_test_post_error_message
-from je_api_testka.utils.api_test_eceptions_tag import api_test_head_error_message
-from je_api_testka.utils.api_test_eceptions_tag import api_test_options_error_message
-from je_api_testka.utils.api_test_eceptions_tag import api_test_patch_error_message
-from je_api_testka.utils.api_test_eceptions_tag import api_test_session_error_message
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_get_error_message
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_put_error_message
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_delete_error_message
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_post_error_message
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_head_error_message
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_options_error_message
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_patch_error_message
+from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_session_error_message
 
 
 exception_message_dict = {
